#
# spec file for package kddockwidgets
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == ""
%define qt5 1
%endif
%if "%{flavor}" == "qt6"
%define qt6 1
%define pkg_suffix -qt6
%endif
%define soversion 2_2
%define rname kddockwidgets
Name:           kddockwidgets%{?pkg_suffix}
Version:        2.2.1
Release:        1.1
Summary:        Qt dock widget library, suitable for replacing QDockWidget
License:        GPL-2.0-only OR GPL-3.0-only
URL:            https://www.kdab.com/development-resources/qt-tools/kddockwidgets
Source:         https://github.com/KDAB/KDDockWidgets/releases/download/v%{version}/%{rname}-%{version}.tar.gz
Source1:        https://github.com/KDAB/KDDockWidgets/releases/download/v%{version}/%{rname}-%{version}.tar.gz.asc
Source2:        kddockwidgets.keyring
BuildRequires:  cmake(nlohmann_json)
%if 0%{?qt5}
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  libqt5-qtdeclarative-private-headers-devel
BuildRequires:  cmake(Qt5Core) >= 5.15
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
%endif
%if 0%{?qt6}
BuildRequires:  qt6-gui-private-devel
BuildRequires:  qt6-quick-private-devel
BuildRequires:  qt6-widgets-private-devel
BuildRequires:  cmake(Qt6Core) >= 6.2
BuildRequires:  cmake(Qt6Quick)
BuildRequires:  cmake(Qt6QuickControls2)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)
%endif
%if 0%{?suse_version} > 1500
# fmt is too old in 15.5/15.6, spdlog can't be used
# FIXME: 2024/07/24: disabled until https://github.com/KDAB/KDDockWidgets/issues/520 is fixed
# BuildRequires:  cmake(spdlog) >= 1.8.0
%else
# Full c++-17 support needed
BuildRequires:  gcc13-PIE
BuildRequires:  gcc13-c++
%endif

%description
KDDockWidgets is a Qt dock widget library written by KDAB, suitable for
replacing QDockWidget and implementing advanced functionalities missing in Qt.

Although KDDockWidgets is ready to be used out of the box, it can also be seen
as a framework to allow building very tailored custom docking systems. It tries
to expose every internal widget and every knob for the app developer to tune.

%package -n libkddockwidgets%{?pkg_suffix}%{?qt6:-}%{soversion}
Summary:        Qt dock widget library, suitable for replacing QDockWidget

%description -n libkddockwidgets%{?pkg_suffix}%{?qt6:-}%{soversion}
KDDockWidgets is a Qt dock widget library written by KDAB, suitable for
replacing QDockWidget and implementing advanced functionalities missing in Qt.

Although KDDockWidgets is ready to be used out of the box, it can also be seen
as a framework to allow building very tailored custom docking systems. It tries
to expose every internal widget and every knob for the app developer to tune.

%package devel
Summary:        Development files for libkddockwidgets
Requires:       libkddockwidgets%{?pkg_suffix}%{?qt6:-}%{soversion} = %{version}
%if 0%{?qt5}
Requires:       cmake(Qt5Quick)
Requires:       cmake(Qt5QuickControls2)
Requires:       cmake(Qt5Widgets)
Requires:       cmake(Qt5X11Extras)
%endif
%if 0%{?qt6}
Requires:       cmake(Qt6Quick)
Requires:       cmake(Qt6QuickControls2)
Requires:       cmake(Qt6Widgets)
%endif

%description devel
Development files for libkddockwidgets

%prep
%autosetup -p1 -n KDDockWidgets-%{version}

%if 0%{?suse_version} < 1550
# examples require cmake >= 3.21
%define extra_opts -DKDDockWidgets_EXAMPLES:BOOL=OFF
%endif

%build
%if 0%{?suse_version} < 1550
export CXX=g++-13
%endif

%if 0%{?qt5}
%cmake %{?extra_opts}
%cmake_build
%endif

%if 0%{?qt6}
%cmake_qt6 -DKDDockWidgets_QT6:BOOL=ON %{?extra_opts}
%{qt6_build}
%endif

%install
%if 0%{?qt5}
%cmake_install
%endif

%if 0%{?qt6}
%{qt6_install}
%endif

# Installed using %%doc and %%license instead
rm -r %{buildroot}%{_datadir}/doc

%ldconfig_scriptlets -n libkddockwidgets%{?pkg_suffix}%{?qt6:-}%{soversion}

%files -n libkddockwidgets%{?pkg_suffix}%{?qt6:-}%{soversion}
%license LICENSES/*
%doc README.md
%{_libdir}/libkddockwidgets%{?pkg_suffix}.so.*

%files devel
%{_includedir}/kddockwidgets%{?pkg_suffix}
%{_libdir}/cmake/KDDockWidgets%{?pkg_suffix}/
%{_libdir}/libkddockwidgets%{?pkg_suffix}.so
%if 0%{?qt5}
%{_libqt5_archdatadir}/mkspecs/modules/qt_KDDockWidgets.pri
%endif
%if 0%{?qt6}
%{_qt6_mkspecsdir}/modules/qt_KDDockWidgets.pri
%endif

%changelog
* Sun Jan 12 2025 Christophe Marin <christophe@krop.fr>
- Update to 2.2.1
  * qtquick: Add support for MainWindowOption_HasCentralWidget
  * qtquick: Add QtQuick::FloatingWindow::setQuickWindowCreationCallback
  * Add Config::setDockWidgetTabIndexOverrideFunc()
  * Allow to redock back to a floating window
  * Add KDDockWidgets::controllersToViews
  * Add Config::setTabsAtBottom()
  * Fix case where persistent central widget would detach when dragged
  * Fix windows having transparency when drop indicators inhibited
  * Fix case where persistent central widget would detach when dragged
  * Allow to build against external KDBindings
  * Fix restore layout of nested main windows
  * Fix restore maximized window corner case
  * Fix linking against static KDDW
* Wed Jul 24 2024 Christophe Marin <christophe@krop.fr>
- Build kddockwidgets without spdlog until fmt 11 gets supported
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 2.1.0
  https://github.com/KDAB/KDDockWidgets/releases/tag/v2.1.0
  Bug fixes:
  * Fixed dock widget float button when using main window nesting
  * Fixed double-click on titlebar not floating it if auto-hide
    flag was enabled
  * Fixed auto-hide overlay not updating its position when main
    window was resized
  * Fixed crash when doing sequential open() and close() calls
  * Fixed double-click the guest widget would make window float
  * LayoutSaverOption::Skip now honours docked dock widgets
  * Fixed DockWidget::addDockWidgetToContainingWindow() when
    using nested main windows
  * Multiple fixes for save/restore when windows are maximized
  * Several fixes regarding nested main windows
* Thu Feb  1 2024 Christophe Marin <christophe@krop.fr>
- Update to 2.0.0
  * Architecture rewrite to support more frontends besides
    QtWidgets and QtQuick. 2.0 isn't very interesting for users,
    but will allow developers to make KDDW support other GUI
    frameworks more easily. Also QtQuick is now better integrated,
    without being shoehorned with ifdefs into the QtWidgets
    implementation.
    + Split into a view/controller architecture
    + Non-gui logic moved to controllers
    + Each controller has a gui counter part, implemented for each
    supported frontend
  * Uses nlohmann JSON library (MIT) instead of QJsonDocument, for
    saving/restoring layouts
  * Added Config::setStartDragDistance()
  * Removed Config::setTabbingAllowedFunc() which was already
    deprecated in favor of Config::setDropIndicatorAllowedFunc()
  * Slint and Flutter WIP. Waiting for these frameworks to
    support multi-window before finishing.
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.7.0
  * Introduce DockWidget::setFloatingWindowFlags(flags).
    Allows for different FloatingWindows to have different window
    flags. For example, some having Qt::Tool while others having
    Qt::Window
  * Fixed fixed-sized windows being able to be resized on Windows
  * Allow restoring layouts without touching floating dock widgets
  * Fix setDropIndicatorsInhibited(false) not showing
    drop indicators
  * Fix relayouting when dock widget is deleted directly
  * Minor performance improvement: Cache TitleBar icons
  * Save side bar overlay geometry when frame is resized
  * Fixed case of corrupt layout when using
    setDockWidgetFactoryFunc()
  * Fix layout scaling factor when main window is native
  * Fix moving floating windows to negative positions
  * Fixed using normal geometry of platform window if
    fractional scaling is enabled
  * Allow to specify Qt::Tool or Qt::Window per floating window
* Wed Mar  1 2023 Christophe Marin <christophe@krop.fr>
- Init kddockwidgets, needed by newer hotspot versions
